==> aws-cdk.aws-synthetics-alpha-2.12.0a0.tar.gz: package/.warnings.jsii.js <==
function _aws_cdk_aws_synthetics_alpha_RuntimeFamily(p) {
}
function _aws_cdk_aws_synthetics_alpha_CronOptions(p) {
}
function _aws_cdk_aws_synthetics_alpha_CustomTestOptions(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.code))
        _aws_cdk_aws_synthetics_alpha_Code(p.code);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_synthetics_alpha_ArtifactsBucketLocation(p) {
}
function _aws_cdk_aws_synthetics_alpha_CodeConfig(p) {
}
function _aws_cdk_aws_synthetics_alpha_Test(p) {
}
function _aws_cdk_aws_synthetics_alpha_InlineCode(p) {
}
function _aws_cdk_aws_synthetics_alpha_AssetCode(p) {
}
function _aws_cdk_aws_synthetics_alpha_S3Code(p) {
}
function _aws_cdk_aws_synthetics_alpha_Schedule(p) {
}
function _aws_cdk_aws_synthetics_alpha_Code(p) {
}
function _aws_cdk_aws_synthetics_alpha_CanaryProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.runtime))
        _aws_cdk_aws_synthetics_alpha_Runtime(p.runtime);
    if (!visitedObjects.has(p.test))
        _aws_cdk_aws_synthetics_alpha_Test(p.test);
    if (!visitedObjects.has(p.artifactsBucketLocation))
        _aws_cdk_aws_synthetics_alpha_ArtifactsBucketLocation(p.artifactsBucketLocation);
    if (!visitedObjects.has(p.schedule))
        _aws_cdk_aws_synthetics_alpha_Schedule(p.schedule);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_synthetics_alpha_Runtime(p) {
}
function _aws_cdk_aws_synthetics_alpha_Canary(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
const visitedObjects = new Set();
class DeprecationError extends Error {
}
module.exports = { print, _aws_cdk_aws_synthetics_alpha_RuntimeFamily, _aws_cdk_aws_synthetics_alpha_CronOptions, _aws_cdk_aws_synthetics_alpha_CustomTestOptions, _aws_cdk_aws_synthetics_alpha_ArtifactsBucketLocation, _aws_cdk_aws_synthetics_alpha_CodeConfig, _aws_cdk_aws_synthetics_alpha_Test, _aws_cdk_aws_synthetics_alpha_InlineCode, _aws_cdk_aws_synthetics_alpha_AssetCode, _aws_cdk_aws_synthetics_alpha_S3Code, _aws_cdk_aws_synthetics_alpha_Schedule, _aws_cdk_aws_synthetics_alpha_Code, _aws_cdk_aws_synthetics_alpha_CanaryProps, _aws_cdk_aws_synthetics_alpha_Runtime, _aws_cdk_aws_synthetics_alpha_Canary };
module.exports.DeprecationError = DeprecationError;

==> aws-cdk.aws-synthetics-alpha-2.18.0a0.tar.gz: package/.warnings.jsii.js <==
function _aws_cdk_aws_synthetics_alpha_RuntimeFamily(p) {
}
function _aws_cdk_aws_synthetics_alpha_CronOptions(p) {
}
function _aws_cdk_aws_synthetics_alpha_CustomTestOptions(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.code))
        _aws_cdk_aws_synthetics_alpha_Code(p.code);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_synthetics_alpha_ArtifactsBucketLocation(p) {
}
function _aws_cdk_aws_synthetics_alpha_CodeConfig(p) {
}
function _aws_cdk_aws_synthetics_alpha_InlineCode(p) {
}
function _aws_cdk_aws_synthetics_alpha_Test(p) {
}
function _aws_cdk_aws_synthetics_alpha_AssetCode(p) {
}
function _aws_cdk_aws_synthetics_alpha_S3Code(p) {
}
function _aws_cdk_aws_synthetics_alpha_Schedule(p) {
}
function _aws_cdk_aws_synthetics_alpha_Code(p) {
}
function _aws_cdk_aws_synthetics_alpha_Runtime(p) {
}
function _aws_cdk_aws_synthetics_alpha_CanaryProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.runtime))
        _aws_cdk_aws_synthetics_alpha_Runtime(p.runtime);
    if (!visitedObjects.has(p.test))
        _aws_cdk_aws_synthetics_alpha_Test(p.test);
    if (!visitedObjects.has(p.artifactsBucketLocation))
        _aws_cdk_aws_synthetics_alpha_ArtifactsBucketLocation(p.artifactsBucketLocation);
    if (!visitedObjects.has(p.schedule))
        _aws_cdk_aws_synthetics_alpha_Schedule(p.schedule);
    if (!visitedObjects.has(p.securityGroups))
        require("aws-cdk-lib/.warnings.jsii.js").aws_cdk_lib_aws_ec2_ISecurityGroup(p.securityGroups);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_synthetics_alpha_Canary(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
const visitedObjects = new Set();
class DeprecationError extends Error {
}
module.exports = { print, _aws_cdk_aws_synthetics_alpha_RuntimeFamily, _aws_cdk_aws_synthetics_alpha_CronOptions, _aws_cdk_aws_synthetics_alpha_CustomTestOptions, _aws_cdk_aws_synthetics_alpha_ArtifactsBucketLocation, _aws_cdk_aws_synthetics_alpha_CodeConfig, _aws_cdk_aws_synthetics_alpha_InlineCode, _aws_cdk_aws_synthetics_alpha_Test, _aws_cdk_aws_synthetics_alpha_AssetCode, _aws_cdk_aws_synthetics_alpha_S3Code, _aws_cdk_aws_synthetics_alpha_Schedule, _aws_cdk_aws_synthetics_alpha_Code, _aws_cdk_aws_synthetics_alpha_Runtime, _aws_cdk_aws_synthetics_alpha_CanaryProps, _aws_cdk_aws_synthetics_alpha_Canary };
module.exports.DeprecationError = DeprecationError;
